# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ChatMode.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x43hatMode.proto\x12\x1e\x41\x63\x46unDanmu.Im.Cloud.Voice.Call*1\n\x08\x43hatMode\x12\x0e\n\nCM_UNKNOWN\x10\x00\x12\x08\n\x04\x43HAT\x10\x01\x12\x0b\n\x07MEETING\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ChatMode_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CHATMODE._serialized_start=50
  _CHATMODE._serialized_end=99
# @@protoc_insertion_point(module_scope)
