# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalWidget.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import WidgetItem_pb2 as WidgetItem__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x43ommonStateSignalWidget.proto\x12\nAcFunDanmu\x1a\x10WidgetItem.proto\"<\n\x17\x43ommonStateSignalWidget\x12!\n\x01\x61\x18\x01 \x03(\x0b\x32\x16.AcFunDanmu.WidgetItemb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalWidget_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALWIDGET._serialized_start=63
  _COMMONSTATESIGNALWIDGET._serialized_end=123
# @@protoc_insertion_point(module_scope)
