# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupInviteReqListResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import GroupInviteRecord_pb2 as GroupInviteRecord__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n GroupInviteReqListResponse.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x17GroupInviteRecord.proto\"r\n\x1aGroupInviteReqListResponse\x12\x44\n\x0cinviteRecord\x18\x01 \x03(\x0b\x32..AcFunDanmu.Im.Cloud.Message.GroupInviteRecord\x12\x0e\n\x06offset\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupInviteReqListResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPINVITEREQLISTRESPONSE._serialized_start=90
  _GROUPINVITEREQLISTRESPONSE._serialized_end=204
# @@protoc_insertion_point(module_scope)
