# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: KwaiStateSignalEcommerceCartItemPopup.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+KwaiStateSignalEcommerceCartItemPopup.proto\x12\nAcFunDanmu\"\xb2\x01\n%KwaiStateSignalEcommerceCartItemPopup\x12\x44\n\x01\x61\x18\x01 \x01(\x0e\x32\x39.AcFunDanmu.KwaiStateSignalEcommerceCartItemPopup.unknown\x12\t\n\x01\x62\x18\x02 \x01(\t\x12\t\n\x01\x63\x18\x03 \x01(\t\x12\t\n\x01\x64\x18\x04 \x01(\t\x12\t\n\x01\x65\x18\x05 \x01(\t\"\x17\n\x07unknown\x12\x05\n\x01\x66\x10\x00\x12\x05\n\x01g\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'KwaiStateSignalEcommerceCartItemPopup_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _KWAISTATESIGNALECOMMERCECARTITEMPOPUP._serialized_start=60
  _KWAISTATESIGNALECOMMERCECARTITEMPOPUP._serialized_end=238
  _KWAISTATESIGNALECOMMERCECARTITEMPOPUP_UNKNOWN._serialized_start=215
  _KWAISTATESIGNALECOMMERCECARTITEMPOPUP_UNKNOWN._serialized_end=238
# @@protoc_insertion_point(module_scope)
