# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: WidgetPictureInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ImageCdnNode_pb2 as ImageCdnNode__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17WidgetPictureInfo.proto\x12\nAcFunDanmu\x1a\x12ImageCdnNode.proto\"N\n\x11WidgetPictureInfo\x12#\n\x01\x61\x18\x01 \x01(\x0b\x32\x18.AcFunDanmu.ImageCdnNode\x12\t\n\x01\x62\x18\x02 \x01(\x05\x12\t\n\x01\x63\x18\x03 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'WidgetPictureInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WIDGETPICTUREINFO._serialized_start=59
  _WIDGETPICTUREINFO._serialized_end=137
# @@protoc_insertion_point(module_scope)
